@@ -39,24 +39,21 @@ Solid::Processor::InstructionSets FakeProcessor::instructionSets() const
 {
     Solid::Processor::InstructionSets result;
 
-    QString str = fakeDevice()->property("instructionSets").toString();
-
-    QStringList extension_list = str.split(',');
-
-    Q_FOREACH (const QString &extension_str, extension_list) {
-        if (extension_str == "mmx") {
+    const QStringList extension_list = fakeDevice()->property("instructionSets").toString().split(',');
+    for (const QString &extension_str : extension_list) {
+        if (extension_str == QLatin1String("mmx")) {
             result |= Solid::Processor::IntelMmx;
-        } else if (extension_str == "sse") {
+        } else if (extension_str == QLatin1String("sse")) {
             result |= Solid::Processor::IntelSse;
-        } else if (extension_str == "sse2") {
+        } else if (extension_str == QLatin1String("sse2")) {
             result |= Solid::Processor::IntelSse2;
-        } else if (extension_str == "sse3") {
+        } else if (extension_str == QLatin1String("sse3")) {
             result |= Solid::Processor::IntelSse3;
-        } else if (extension_str == "sse4") {
+        } else if (extension_str == QLatin1String("sse4")) {
             result |= Solid::Processor::IntelSse4;
-        } else if (extension_str == "3dnow") {
+        } else if (extension_str == QLatin1String("3dnow")) {
             result |= Solid::Processor::Amd3DNow;
-        } else if (extension_str == "altivec") {
+        } else if (extension_str == QLatin1String("altivec")) {
             result |= Solid::Processor::AltiVec;
         }
     }
